@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from WebKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestWebKitErrors (TestCase):
     def testConstants(self):
         self.assertIsInstance(WebKitErrorDomain, unicode)
@@ -20,8 +15,7 @@ class TestWebKitErrors (TestCase):
         self.assertEqual(WebKitErrorCannotFindPlugIn, 200)
         self.assertEqual(WebKitErrorCannotLoadPlugIn, 201)
         self.assertEqual(WebKitErrorJavaUnavailable, 202)
-
-
+        self.assertEqual(WebKitErrorBlockedPlugInVersion, 203)
 
 
 if __name__ == "__main__":
